<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<!--The customized transformations-->
	<!--xsl:import href="Custom.xsl"/-->
	<xsl:output method="html" indent="yes" standalone="yes" encoding="ISO-8859-1"/>
	<!--The file that contains the I18N translations-->
	<xsl:param name="I18N_file" select="'CV.I18N.xml'"/>
	<!--The XML file that contains the CSS that should be embedded in the generated HTML-->
	<xsl:param name="css_file"/>
	<!--The file that contains the companies descriptions-->
	<xsl:param name="companies_file" select="'Companies.xml'"/>
	<xsl:template match="Document">
		<html>
			<head>
				<!--style type="text/css">
					<xsl:value-of select="document($css_file)/Style"/>
				</style-->
				<script language="JavaScript" type="text/javascript" src="CV.js"/>
				<title>
					<xsl:value-of select="Name"/>
				</title>
			</head>
			<body>
				<xsl:apply-templates select="Person"/>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="Person">
		<xsl:call-template name="print_resume_content"/>
	</xsl:template>
	<xsl:template match="Experience">
		<table>
			<colgroup>
				<col span="1" width="100"/>
			</colgroup>
			<xsl:variable name="detail_id" select="generate-id(Detail)"/>
			<tr>
				<td>
					<b>
						<xsl:apply-templates select="Start"/>
					</b>
					<xsl:if test="count(End) > 0">
						<xsl:text> - </xsl:text>
						<b>
							<xsl:apply-templates select="End"/>
						</b>
					</xsl:if>
					<xsl:variable name="indent" select="count(ancestor::Experience)"/>
				</td>
				<!--xsl:if test='$detail_id != ""'>
					<td>
						<img src="triangleRight.gif" onclick="expandTheElement({$detail_id})">
							<xsl:attribute name="alt"><xsl:call-template name="getI18N"><xsl:with-param name="key" select="'expand_collapse'"/></xsl:call-template></xsl:attribute>
						</img>
					</td>
				</xsl:if-->
				<th id="block">
					<xsl:apply-templates select="Company"/>
				</th>
			</tr>
			<xsl:variable name="sub_experience_number" select="count(Experience)"/>
			<tr>
				<td id="block">
					<xsl:attribute name="rowspan"><xsl:value-of select="$sub_experience_number + 2"/></xsl:attribute>
				</td>
				<td class="overview">
					<xsl:apply-templates select="Overview"/>
				</td>
			</tr>
			<tr id="{$detail_id}">
				<td class="detail">
					<xsl:apply-templates select="Detail"/>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:for-each select="Experience">
						<xsl:sort order="descending" select="Start/Date/@year"/>
						<xsl:sort order="descending" select="Start/Date/@month"/>
						<xsl:sort order="descending" select="Start/Date/@day"/>
						<xsl:apply-templates select="."/>
					</xsl:for-each>
				</td>
			</tr>
		</table>
	</xsl:template>
	<xsl:template match="Company">
		<xsl:variable name="id">
			<xsl:choose>
				<xsl:when test="count(@IDREF) > 0">
					<xsl:value-of select="@IDREF"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="@ID"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="company" select="document($companies_file)//Company[@ID=$id]"/>
		<xsl:apply-templates select="$company/Name"/>
		<xsl:if test="count($company/Mother) > 0">
			<xsl:variable name="mother" select="document($companies_file)//Company[@ID=$company/Mother/@IDREF]"/>
			<xsl:text> (</xsl:text>
			<xsl:apply-templates select="$mother"/>
			<xsl:text>)</xsl:text>
		</xsl:if>
	</xsl:template>
	<xsl:template match="//Detail//p">
		<p>
			<xsl:apply-templates/>
		</p>
	</xsl:template>
	<xsl:template name="getI18N">
		<xsl:param name="key"/>
		<xsl:variable name="result" select="document($I18N_file)/I18NS//I18N[@key=$key]"/>
		<xsl:value-of select="$result/I18[@xml:lang=$lang]"/>
	</xsl:template>
	<!--Prints the HTML content of the resume, with no HTML header-->
	<!--The current node must be the Person element-->
	<xsl:template name="print_resume_content">
		<table width="100%">
			<colgroup>
				<col span="1"/>
				<col span="1" align="right"/>
			</colgroup>
			<tr>
				<td>
					<font size="+2">
						<xsl:value-of select="Name"/>
					</font>
				</td>
				<td>
					<xsl:apply-templates select="Birthdate"/>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:value-of select="Address"/>
				</td>
				<td>
					<xsl:apply-templates select="Citizenship"/>
				</td>
			</tr>
			<tr>
				<td>
					<table>
						<xsl:for-each select="Phone">
							<tr>
								<td align="left">
									<xsl:apply-templates select="."/>
								</td>
							</tr>
						</xsl:for-each>
					</table>
				</td>
				<td>
					<table>
						<xsl:for-each select="Email">
							<tr>
								<td align="left">
									<xsl:apply-templates select="."/>
								</td>
							</tr>
						</xsl:for-each>
					</table>
				</td>
			</tr>
			<tr>
				<td align="right">
					<xsl:apply-templates select="Website"/>
				</td>
			</tr>
		</table>
		<hr/>
		<h2>
			<xsl:call-template name="getI18N">
				<xsl:with-param name="key" select="'Experience'"/>
			</xsl:call-template>
		</h2>
		<h3>
			<xsl:call-template name="getI18N">
				<xsl:with-param name="key" select="'Professional'"/>
			</xsl:call-template>
		</h3>
		<xsl:for-each select="Experiences/Experience[@type='pro' or @type='stage']">
			<xsl:sort order="descending" select="Start/Date/@year"/>
			<xsl:sort order="descending" select="Start/Date/@month"/>
			<xsl:apply-templates select="."/>
		</xsl:for-each>
		<h3>
			<xsl:call-template name="getI18N">
				<xsl:with-param name="key" select="'Personal'"/>
			</xsl:call-template>
		</h3>
		<xsl:apply-templates select="Experiences/Experience[@type='perso']">
			<xsl:sort order="descending" select="Start"/>
		</xsl:apply-templates>
		<h2>
			<xsl:call-template name="getI18N">
				<xsl:with-param name="key" select="'Education'"/>
			</xsl:call-template>
		</h2>
		<table>
			<xsl:for-each select="Educations/Education">
				<xsl:sort order="descending" select="Start"/>
				<tr>
					<td>
						<b>
							<xsl:apply-templates select="Start"/>
						</b>
						<xsl:text> - </xsl:text>
						<b>
							<xsl:apply-templates select="End"/>
						</b>
					</td>
					<td>
						<xsl:apply-templates select="Description"/>
					</td>
				</tr>
			</xsl:for-each>
		</table>
		<h2>
			<xsl:call-template name="getI18N">
				<xsl:with-param name="key" select="'Ability'"/>
			</xsl:call-template>
		</h2>
		<table>
			<xsl:for-each select="Abilities/Ability[@type='computing']">
				<tr>
					<xsl:if test="(position() mod 2) = 0">
						<xsl:attribute name="class">even</xsl:attribute>
					</xsl:if>
					<th>
						<xsl:apply-templates select="Title"/>
					</th>
					<td>
						<xsl:apply-templates select="Description"/>
					</td>
				</tr>
			</xsl:for-each>
		</table>
		<h2>
			<xsl:call-template name="getI18N">
				<xsl:with-param name="key" select="'Language'"/>
			</xsl:call-template>
		</h2>
		<table>
			<xsl:for-each select="Abilities/Ability[@type='language']">
				<tr>
					<xsl:if test="(position() mod 2) = 0">
						<xsl:attribute name="class">even</xsl:attribute>
					</xsl:if>
					<th>
						<xsl:apply-templates select="Title"/>
					</th>
					<td>
						<xsl:apply-templates select="Description"/>
					</td>
				</tr>
			</xsl:for-each>
		</table>
		<hr/>
	</xsl:template>
</xsl:stylesheet>
