<?xml version="1.0" encoding="ISO-8859-1"?>
<!--
The aim of that XSL file is to define/override the system generation should resolve things that need to be customized for your own purpose.
Important things:
1. this enables to resolve external entities,
2. this enables to define some extra code within the HTML head element.
-->
<!--The customized XSL file.-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://icl.com/saxon" extension-element-prefixes="saxon">
	<!--The common transformations-->
	<xsl:import href="Common.xsl"/>
	<!--
	Called when the transformation needs to resolve a URL from a Document reference. The method prints the document URL that the integrating system can handle with.
	The id and xml:lang parameters are expected.
	-->
	<xsl:template name="print_document_url">
		<xsl:param name="id"/>
		<xsl:param name="xml:lang"/>
		<xsl:choose>
			<xsl:when test="$single_document">
				<xsl:text>../</xsl:text>
				<xsl:value-of select="$id"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="print_html_target_file_path">
					<xsl:with-param name="idref" select="$id"/>
					<xsl:with-param name="xml:lang" select="$xml:lang"/>
					<xsl:with-param name="url" select="'yes'"/>
					<xsl:with-param name="relative" select="'yes'"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Called when the system needs an XML document source, given its id.
	The id parameter is expected.
	-->
	<xsl:template name="print_xml_document_source">
		<xsl:param name="id"/>
		<xsl:choose>
			<xsl:when test="$single_document">
				<xsl:text>../</xsl:text>
				<xsl:value-of select="$id"/>
				<xsl:text>/body</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$id"/>
				<xsl:text>.xml</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Called when the system needs an XML document, given its id.
	The id parameter is expected.
	-->
	<xsl:template name="print_xml_document_content">
		<xsl:param name="id"/>
		<xsl:variable name="url">
			<xsl:call-template name="print_xml_document_source">
				<xsl:with-param name="id" select="$id"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:copy-of select="document('$url')"/>
	</xsl:template>
	<!--
	Called when generating a HTML header element: what this template prints is the extra header stuff that is needed everytime.
	-->
	<xsl:template name="print_extra_header">
		<script type="text/javascript" language="javascript">
			<xsl:attribute name="src"><xsl:call-template name="_print_javascript_path"/></xsl:attribute>
		</script>
	</xsl:template>
</xsl:stylesheet>
