<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
This XSL yields some HTML release note, which encompasses all the releases of the component described by the XML entry file.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:include href="XMLReleaseNotes2HTML.xsl"/>
	<xsl:template match="Releases">
		<xsl:for-each select="document(@href)/Component[1]">
			<xsl:call-template name="_printReleaseNotes"/>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="ReleaseNotes">
		<xsl:call-template name="_printReleaseNotes"/>
	</xsl:template>
	<xsl:template match="XMLReleaseNotes">
		<xsl:apply-templates select="document(@href)">
			<xsl:with-param name="standAloneHTML" select="'false'"/>
		</xsl:apply-templates>
	</xsl:template>
	<!--
	The current node should contain all the 'Release' XML element that make the release notes.
	-->
	<xsl:template name="_printReleaseNotes">
		<table border="1" width="100%">
			<tr>
				<th width="10%">Version</th>
				<th>Content</th>
				<th width="15%">Download</th>
			</tr>
			<xsl:for-each select="Release">
				<tr>
					<xsl:if test="@status">
						<xsl:attribute name="class"><xsl:value-of select="@status"/></xsl:attribute>
					</xsl:if>
					<td>
						<code>
							<b>
								<font size="+2">
									<xsl:value-of select="@version"/>
								</font>
							</b>
						</code>
						<xsl:if test="@date">
							<br/>[<xsl:value-of select="@date"/>]</xsl:if>
					</td>
					<td>
						<xsl:if test="Summary">
							<blockquote>
								<dl>
									<b>Summary:</b>
									<dd>
										<xsl:apply-templates select="Summary"/>
									</dd>
								</dl>
							</blockquote>
						</xsl:if>
						<xsl:if test="count(Component) > 0">
							<blockquote>
								<dl>
									<b>Composition:</b>
									<xsl:for-each select="Component">
										<dd>
											<xsl:value-of select="@name"/>
											<xsl:text/>
											<xsl:value-of select="@version"/>
										</dd>
									</xsl:for-each>
								</dl>
							</blockquote>
						</xsl:if>
						<ul>
							<xsl:for-each select="Token">
								<li>
									<xsl:if test="@type">
										<code>[<xsl:value-of select="@type"/>
											<xsl:text>] </xsl:text>
										</code>
									</xsl:if>
									<xsl:apply-templates select="."/>
								</li>
							</xsl:for-each>
						</ul>
						<xsl:if test="NB">
							<blockquote>
								<dl>
									<b>NB:</b>
									<dd>
										<xsl:apply-templates select="NB"/>
									</dd>
								</dl>
							</blockquote>
						</xsl:if>
					</td>
					<td>
						<xsl:choose>
							<xsl:when test="Download">
								<ul>
									<xsl:for-each select="Download">
										<li>
											<xsl:apply-templates select="."/>
										</li>
									</xsl:for-each>
								</ul>
							</xsl:when>
							<xsl:when test="@download">
								<a>
									<xsl:attribute name="href"><xsl:value-of select="@download"/></xsl:attribute>download</a>
							</xsl:when>
							<xsl:otherwise>No download available</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
			</xsl:for-each>
		</table>
	</xsl:template>
</xsl:stylesheet>
